@@ -13,6 +13,7 @@ __copyright__ = "Copyright 2022, CAST Software"
 
 #class that allows the connexion to the database
 class ActionPlan():
+    
 
     def __init__(self, config:Config, log_level=INFO):
         self.logger = Logger(self.__class__.__name__, log_level)
@@ -26,14 +27,15 @@ class ActionPlan():
                 raise RuntimeError('rules file not found')
 
             self.file_name = abspath(f'{getsitepackages()[-1]}/cast_action_plan/rules.xlsx')
+            self.logger.info(f'Rules file is at: {self.file_name}')
             if not exists(self.file_name):
                 raise RuntimeError(f'{self.file_name} not found')
         else:
             raise RuntimeError("Database connection error")
 
-    def _open_database (self, config:Config) -> bool:
+    def open_database (self, config:Config) -> bool:
         try:
-            conn = connect(database=config.db_database, user=config.db_user, password=config.db_password, host=config.db_host, port=config.db_port)
+            conn = connect(database=config.database, user=config.user, password=config.password, host=config.host, port=config.port)
             self._connection = conn
             self._session = conn.cursor()
             self.logger.debug("Connected to the database")
@@ -48,14 +50,13 @@ class ActionPlan():
 
    
     def fetch_data(self, app_name):
-
         self.logger.info(f"Retriving existing action items for {app_name}")
         db_full_name=f'{app_name}_central'.replace("-","_").replace(".","_")
         query_path = f'set search_path={db_full_name}'
         query = "select distinct dmv.metric_id, dmv.snapshot_id, dmv.functional_date, dmr.object_id from dss_metric_values dmv, dss_metric_results dmr where dmv.metric_id = dmr.metric_id order by dmv.metric_id asc"
         self._session.execute(query_path,query)
 
-        #delete the content of the viewer_action_plan
+        #delete the content of thfge viewer_action_plan
         sql=f'Delete from {db_full_name}.viewer_action_plans'
         self._session.execute(sql)
         self._connection.commit()
