@@ -13,7 +13,9 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     try:
-        db = ActionPlan(Config(args.config))
+        config = Config(args.config)
+        db = ActionPlan(config)
+        db.open_database(config)
         db.run(args.appl_name)
     except RuntimeError as re:
         print(re)
